@@ -105,7 +105,7 @@ The cache automatically tracks when matrix `A` or parameters `p` change by setti
 appropriate freshness flags. When `solve!` is called, stale cache entries are automatically
 recomputed as needed.
 """
-mutable struct LinearCache{TA, Tb, Tu, Tp, Talg, Tc, Tl, Tr, Ttol, issq, S}
+mutable struct LinearCache{TA, Tb, Tu, Tp, Talg, Tc, Tl, Tr, Ttol, Tlv <: LinearVerbosity, issq, S}
     A::TA
     b::Tb
     u::Tu
@@ -119,7 +119,7 @@ mutable struct LinearCache{TA, Tb, Tu, Tp, Talg, Tc, Tl, Tr, Ttol, issq, S}
     abstol::Ttol
     reltol::Ttol
     maxiters::Int
-    verbose::LinearVerbosity
+    verbose::Tlv
     assumptions::OperatorAssumptions{issq}
     sensealg::S
 end
@@ -232,6 +232,21 @@ default_alias_b(::AbstractSparseFactorization, ::Any, ::Any) = true
 
 DEFAULT_PRECS(A, p) = IdentityOperator(size(A)[1]), IdentityOperator(size(A)[2])
 
+# Default verbose setting (const for type stability)
+const DEFAULT_VERBOSE = LinearVerbosity()
+
+# Helper functions for processing verbose parameter with multiple dispatch (type-stable)
+@inline _process_verbose_param(verbose::LinearVerbosity) = (verbose, verbose)
+@inline function _process_verbose_param(verbose::SciMLLogging.AbstractVerbosityPreset)
+    verbose_spec = LinearVerbosity(verbose)
+    return (verbose_spec, verbose_spec)
+end
+@inline function _process_verbose_param(verbose::Bool)
+    # @warn "Using `true` or `false` for `verbose` is being deprecated."
+    verbose_spec = verbose ? DEFAULT_VERBOSE : LinearVerbosity(SciMLLogging.None())
+    return (verbose_spec, verbose)
+end
+
 """
     __init_u0_from_Ab(A, b)
 
@@ -267,7 +282,7 @@ function __init(prob::LinearProblem, alg::SciMLLinearSolveAlgorithm,
         abstol = default_tol(real(eltype(prob.b))),
         reltol = default_tol(real(eltype(prob.b))),
         maxiters::Int = length(prob.b),
-        verbose = true,
+        verbose = LinearVerbosity(),
         Pl = nothing,
         Pr = nothing,
         assumptions = OperatorAssumptions(issquare(prob.A)),
@@ -324,22 +339,7 @@ function __init(prob::LinearProblem, alg::SciMLLinearSolveAlgorithm,
         copy(A)
     end
 
-    if verbose isa Bool
-        # @warn "Using `true` or `false` for `verbose` is being deprecated. Please use a `LinearVerbosity` type to specify verbosity settings.
-        # For details see the verbosity section of the common solver options documentation page."
-        init_cache_verb = verbose
-        if verbose 
-            verbose_spec = LinearVerbosity()
-        else
-            verbose_spec = LinearVerbosity(SciMLLogging.None())
-        end
-    elseif verbose isa SciMLLogging.AbstractVerbosityPreset
-        verbose_spec = LinearVerbosity(verbose)
-        init_cache_verb = verbose_spec
-    else
-        verbose_spec = verbose
-        init_cache_verb = verbose_spec
-    end
+    verbose_spec, init_cache_verb = _process_verbose_param(verbose)
 
     b = if issparsematrix(b) && !(A isa Diagonal)
         Array(b) # the solution to a linear solve will always be dense!
@@ -357,8 +357,8 @@ function __init(prob::LinearProblem, alg::SciMLLinearSolveAlgorithm,
     u0_ = u0 !== nothing ? u0 : __init_u0_from_Ab(A, b)
 
     # Guard against type mismatch for user-specified reltol/abstol
-    reltol = real(eltype(prob.b))(reltol)
-    abstol = real(eltype(prob.b))(abstol)
+    reltol = real(eltype(prob.b))(SciMLBase.value(reltol))
+    abstol = real(eltype(prob.b))(SciMLBase.value(abstol))
 
     precs = if hasproperty(alg, :precs)
         isnothing(alg.precs) ? DEFAULT_PRECS : alg.precs
@@ -385,7 +385,7 @@ function __init(prob::LinearProblem, alg::SciMLLinearSolveAlgorithm,
     Tc = typeof(cacheval)
 
     cache = LinearCache{typeof(A), typeof(b), typeof(u0_), typeof(p), typeof(alg), Tc,
-        typeof(Pl), typeof(Pr), typeof(reltol), typeof(assumptions.issq),
+        typeof(Pl), typeof(Pr), typeof(reltol), typeof(verbose_spec), typeof(assumptions.issq),
         typeof(sensealg)}(
         A, b, u0_, p, alg, cacheval, isfresh, precsisfresh, Pl, Pr, abstol, reltol,
         maxiters, verbose_spec, assumptions, sensealg)
@@ -478,3 +478,22 @@ function SciMLBase.solve(prob::StaticLinearProblem,
     return SciMLBase.build_linear_solution(
         alg, u, nothing, prob; retcode = ReturnCode.Success)
 end
+
+function update_tolerances!(cache; abstol = nothing, reltol = nothing)
+    if abstol !== nothing
+        cache.abstol = abstol
+    end
+    if reltol !== nothing
+        cache.reltol = reltol
+    end
+    update_tolerances_internal!(cache, cache.alg, abstol, reltol)
+end
+
+
+function update_tolerances_internal!(cache, alg::AbstractFactorization, abstol, reltol)
+    error("Cannot update tolerances for factorization.")
+end
+
+function update_tolerances_internal!(cache, alg::AbstractKrylovSubspaceMethod, abstol, reltol)
+    @warn "Tolerance update for Krylov subspace method '$typeof(alg)' not implemented." maxlog = 1
+end
